# Upstream uses weird versioning convention
%global upstreamver 2.3_1-opensource

### Qt5 libraries
%define libname_major     1
%define libname_qt5       %mklibname qt5iocompressor %{libname_major}
%define libname_devel_qt5 %mklibname qt5iocompressor -d

Summary:        QIODevice that compresses data streams
Name:           qtiocompressor
Version:        2.3.1
Release:        %mkrel 6
Group:          Development/KDE and Qt
License:        GPLv3 or LGPLv2 with exceptions
URL:            http://qt.nokia.com/products/appdev/add-on-products/catalog/4/Utilities/qtiocompressor/
# The original source was http://get.qt.nokia.com/qt/solutions/lgpl/qtiocompressor-%%{upstreamver}.tar.gz but is unavailable.
# A merge request to reimport this module to qt-solutions is already open at https://codereview.qt-project.org/#/c/58895/
Source0:        https://fale.fedorapeople.org/qtiocompressor/qtiocompressor-%{upstreamver}.tar.gz
# To add qmake support for convenience for packages using this library:
# http://bugreports.qt.nokia.com/browse/QTSOLBUG-119
Source1:        qtiocompressor.prf

# Don't build examples:
Patch0:         qtiocompressor-build.patch
# Use Qt5 library
Patch1:         qtiocompressor-2.3.1_use-qt5-lib.patch
# Use system zlib
Patch2:         qtiocompressor-system-zlib.patch

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(zlib)

%description
The class works on top of a QIODevice subclass, compressing data before it is
written and decompressing it when it is read. Since QtIOCompressor works on
streams, it does not have to see the entire data set before compressing or
decompressing it. This can reduce the memory requirements when working on large
data sets.

# ----------------------------

%package -n     %libname_qt5
Summary:        QIODevice that compresses data streams
Group:          Development/KDE and Qt

%description -n %libname_qt5
The class works on top of a QIODevice subclass, compressing data before it is
written and decompressing it when it is read. Since QtIOCompressor works on
streams, it does not have to see the entire data set before compressing or
decompressing it. This can reduce the memory requirements when working on large
data sets.

%files -n %libname_qt5
%doc README.TXT
%license LGPL_EXCEPTION.txt LICENSE.*
%{_qt5_libdir}/lib*Qt5Solutions_IOCompressor*.so.%{libname_major}{,.*}

# ----------------------------

%package -n     %{libname_devel_qt5}
Summary:        Development files for %{name}
Group:          Development/KDE and Qt
Requires:       %{libname_qt5} = %{version}-%{release}
Provides:       %{name}-qt5-devel = %{version}-%{release}
Provides:       qt5iocompressor-devel = %{version}-%{release}

%description -n %{libname_devel_qt5}
This package contains libraries and header files for developing applications
that use QtIOCompressor.

%files -n %{libname_devel_qt5}
%doc doc examples
%{_qt5_libdir}/lib*Qt5Solutions_IOCompressor*.so
%{_qt5_includedir}/QtSolutions/
%{_qt5_libdir}/qt5/mkspecs/features/%{name}.prf

# ----------------------------

%prep
%autosetup -p1 -n %{name}-%{upstreamver}

%build
touch .licenseAccepted
# Does not use GNU configure
./configure -library

%qmake_qt5 QMAKE_CFLAGS_ISYSTEM=
%make_build

%install
# libraries
mkdir -p %{buildroot}%{_qt5_libdir}
cp -a lib/* %{buildroot}%{_qt5_libdir}
chmod 755 %{buildroot}%{_qt5_libdir}/*.so.*.*.*

# headers
mkdir -p %{buildroot}%{_qt5_includedir}/QtSolutions
cp -a \
    src/qtiocompressor.h \
    src/QtIOCompressor \
    %{buildroot}%{_qt5_includedir}/QtSolutions

mkdir -p %{buildroot}%{_qt5_libdir}/qt5/mkspecs/features/
cp -a %{SOURCE1} %{buildroot}%{_qt5_libdir}/qt5/mkspecs/features/


%changelog
* Sun Apr 03 2022 umeabot <umeabot> 2.3.1-6.mga9
+ Revision: 1842190
- Mageia 9 Mass Rebuild

* Thu Dec 17 2020 umeabot <umeabot> 2.3.1-5.mga8
+ Revision: 1659629
- Rebuild for new Qt5

* Sat Feb 15 2020 umeabot <umeabot> 2.3.1-4.mga8
+ Revision: 1527912
- Mageia 8 Mass Rebuild

* Sat Jul 27 2019 daviddavid <daviddavid> 2.3.1-3.mga8
+ Revision: 1424495
- rebuild for new Qt5 headers path

* Mon Apr 01 2019 umeabot <umeabot> 2.3.1-2.mga7
+ Revision: 1384441
- Qt5 Rebuild

* Wed Jan 16 2019 daviddavid <daviddavid> 2.3.1-1.mga7
+ Revision: 1357462
- initial package qtiocompressor

